@@ -98,10 +98,9 @@
 #'          Use \code{"l"} for upper left corner.
 #' @param axis.titles character vector of length one or two, defining the title(s)
 #'          for the x-axis and y-axis.
-#' @param drop.empty Logical, if \code{TRUE} and the variable's values are labeled,
-#'          values that have no observations are still printed in the table (with
-#'          frequency \code{0}). If \code{FALSE}, values / factor levels with no occurrence
-#'          in the data are omitted from the output.
+#' @param drop.empty Logical, if \code{TRUE} and the variable's values are labeled, values / factor
+#'          levels with no occurrence in the data are omitted from the output. If \code{FALSE},
+#'          labeled values that have no observations are still printed in the table (with frequency \code{0}).
 #' @param auto.group numeric value, indicating the minimum amount of unique values
 #'          in the count variable, at which automatic grouping into smaller units
 #'          is done (see \code{\link[sjmisc]{group_var}}). Default value for
@@ -650,9 +649,9 @@ plot_grpfrq <- function(var.cnt,
       geob <- geom_bar(stat = "identity", width = geom.size, position = position_stack(reverse = TRUE))
   } else if (type == "line") {
     if (smooth.lines)
-      geob <- geom_line(size = geom.size, stat = "smooth", method = "loess")
+      geob <- geom_line(linewidth = geom.size, stat = "smooth", method = "loess")
     else
-      geob <- geom_line(size = geom.size)
+      geob <- geom_line(linewidth = geom.size)
   } else if (type == "boxplot") {
       geob <- geom_boxplot(width = geom.size, notch = show.ci)
   } else if (type == "violin") {
@@ -822,7 +821,7 @@ plot_grpfrq <- function(var.cnt,
 
   # If we have bars or dot plots, we show
   # Pearson's chi-square test results
-  baseplot <- print.table.summary(baseplot, modsum, summary.pos)
+  baseplot <- .print.table.summary(baseplot, modsum, summary.pos)
 
   # prepare y-axis and
   # show or hide y-axis-labels
